@@ -697,8 +697,8 @@ et_canvas_realize (GtkWidget *canvas, ETable *e_table)
 		NULL);
 }
 
-static void
-et_canvas_button_press (GtkWidget *canvas, GdkEvent *event, ETable *e_table)
+static gint
+et_canvas_button_press (GtkWidget *canvas, GdkEventButton *event, ETable *e_table)
 {
 	if (GTK_WIDGET_HAS_FOCUS(canvas)) {
 		GnomeCanvasItem *item = GNOME_CANVAS(canvas)->focused_item;
@@ -707,6 +707,8 @@ et_canvas_button_press (GtkWidget *canvas, GdkEvent *event, ETable *e_table)
 			e_table_item_leave_edit(E_TABLE_ITEM(item));
 		}
 	}
+
+	return FALSE;
 }
 
 static void
@@ -1050,6 +1052,8 @@ et_real_construct (ETable *e_table, ETableModel *etm, ETableExtras *ete,
 
 	gtk_layout_get_vadjustment (GTK_LAYOUT (e_table->table_canvas))->step_increment = 20;
 	gtk_adjustment_changed(gtk_layout_get_vadjustment (GTK_LAYOUT (e_table->table_canvas)));
+	gtk_layout_get_hadjustment (GTK_LAYOUT (e_table->table_canvas))->step_increment = 20;
+	gtk_adjustment_changed(gtk_layout_get_hadjustment (GTK_LAYOUT (e_table->table_canvas)));
 
 	if (!specification->no_headers) {
 		/*
@@ -1404,6 +1408,12 @@ e_table_get_printable (ETable *e_table)
 	return e_table_group_get_printable(e_table->group);
 }
 
+void
+e_table_right_click_up (ETable *table)
+{
+	e_selection_model_right_click_up(E_SELECTION_MODEL(table->selection));
+}
+
 static void
 et_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 {
@@ -1451,6 +1461,10 @@ set_scroll_adjustments   (ETable *table,
 		vadjustment->step_increment = 20;
 		gtk_adjustment_changed(vadjustment);
 	}
+	if (hadjustment != NULL) {
+		hadjustment->step_increment = 20;
+		gtk_adjustment_changed(hadjustment);
+	}
 
 	gtk_layout_set_hadjustment (GTK_LAYOUT(table->table_canvas),
 				    hadjustment);
