@@ -679,8 +679,8 @@ et_canvas_realize (GtkWidget *canvas, ETree *e_tree)
 		NULL);
 }
 
-static void
-et_canvas_button_press (GtkWidget *canvas, GdkEvent *event, ETree *e_tree)
+static gint
+et_canvas_button_press (GtkWidget *canvas, GdkEventButton *event, ETree *e_tree)
 {
 	if (GTK_WIDGET_HAS_FOCUS(canvas)) {
 		GnomeCanvasItem *item = GNOME_CANVAS(canvas)->focused_item;
@@ -689,6 +689,8 @@ et_canvas_button_press (GtkWidget *canvas, GdkEvent *event, ETree *e_tree)
 			e_table_item_leave_edit(E_TABLE_ITEM(item));
 		}
 	}
+
+	return FALSE;
 }
 
 static void
@@ -1038,6 +1040,8 @@ et_real_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
 
 	gtk_layout_get_vadjustment (GTK_LAYOUT (e_tree->priv->table_canvas))->step_increment = 20;
 	gtk_adjustment_changed(gtk_layout_get_vadjustment (GTK_LAYOUT (e_tree->priv->table_canvas)));
+	gtk_layout_get_hadjustment (GTK_LAYOUT (e_tree->priv->table_canvas))->step_increment = 20;
+	gtk_adjustment_changed(gtk_layout_get_hadjustment (GTK_LAYOUT (e_tree->priv->table_canvas)));
 
 	if (!specification->no_headers) {
 		/*
@@ -1344,6 +1348,10 @@ set_scroll_adjustments   (ETree *tree,
 		vadjustment->step_increment = 20;
 		gtk_adjustment_changed(vadjustment);
 	}
+	if (hadjustment != NULL) {
+		hadjustment->step_increment = 20;
+		gtk_adjustment_changed(hadjustment);
+	}
 
 	gtk_layout_set_hadjustment (GTK_LAYOUT(tree->priv->table_canvas),
 				    hadjustment);
@@ -1526,6 +1534,12 @@ e_tree_get_tooltip (ETree *et)
 	return E_CANVAS(et->priv->table_canvas)->tooltip_window;
 }
 
+void
+e_tree_right_click_up (ETree *et)
+{
+	e_selection_model_right_click_up(et->priv->selection);
+}
+
 /**
  * e_tree_get_model:
  * @et: the ETree
