@@ -9,6 +9,7 @@
 #include <gal/widgets/e-printable.h>
 
 #include <gal/e-table/e-table-extras.h>
+#include <gal/e-table/e-table-specification.h>
 #include <gal/e-table/e-table-state.h>
 #include <gal/e-table/e-tree-model.h>
 
@@ -45,6 +46,7 @@ typedef struct {
 	gint        (*right_click)        (ETree *et, int row, ETreePath path, int col, GdkEvent *event);
 	gint        (*click)              (ETree *et, int row, ETreePath path, int col, GdkEvent *event);
 	gint        (*key_press)          (ETree *et, int row, ETreePath path, int col, GdkEvent *event);
+	gint        (*start_drag)         (ETree *et, int row, ETreePath path, int col, GdkEvent *event);
 
 	void  (*set_scroll_adjustments)   (ETree	 *tree,
 					   GtkAdjustment *hadjustment,
@@ -137,6 +139,7 @@ gchar          *e_tree_get_state                  (ETree                *e_tree)
 void            e_tree_save_state                 (ETree                *e_tree,
 						   const gchar          *filename);
 ETableState    *e_tree_get_state_object           (ETree                *e_tree);
+ETableSpecification    *e_tree_get_spec           (ETree                *e_tree);
 
 /* note that it is more efficient to provide the state at creation time */
 void            e_tree_set_state                  (ETree                *e_tree,
@@ -256,6 +259,9 @@ void            e_tree_load_expanded_state        (ETree                *et,
 int             e_tree_row_count                  (ETree                *et);
 GtkWidget      *e_tree_get_tooltip                (ETree                *et);
 
+/* This function is only needed in single_selection_mode. */
+void            e_tree_right_click_up             (ETree                *et);
+
 END_GNOME_DECLS
 
 #endif /* _E_TREE_H_ */
