@@ -419,6 +419,27 @@ e_shortcut_bar_on_item_updated (EShortcutModel *model,
 				    item_url, item_name, image);
 }
 
+static void
+e_shortcut_bar_group_button_press (GtkWidget *widget,
+				   GdkEventButton *button_event,
+				   EShortcutBar *shortcut_bar)
+{
+	EGroupBar *group_bar;
+	int i;
+
+	group_bar = E_GROUP_BAR (shortcut_bar);
+
+	for (i = 0; i < group_bar->children->len; i++) {
+		EGroupBarChild *child;
+
+		child = &g_array_index (group_bar->children, EGroupBarChild, i);
+		if (widget == child->button) {
+			gtk_signal_emit (GTK_OBJECT (shortcut_bar), e_shortcut_bar_signals[ITEM_SELECTED],
+					 button_event, i, -1);
+			break;
+		}
+	}
+}
 
 static gint
 e_shortcut_bar_add_group	(EShortcutBar	*shortcut_bar,
@@ -480,6 +501,10 @@ e_shortcut_bar_add_group	(EShortcutBar	*shortcut_bar,
 #endif
 
 	button = gtk_button_new ();
+	gtk_signal_connect (GTK_OBJECT (button), "button_press_event",
+			    GTK_SIGNAL_FUNC (e_shortcut_bar_group_button_press),
+			    shortcut_bar);
+
 	label = e_entry_new ();
 	gtk_object_set(GTK_OBJECT(label),
 		       "draw_background", FALSE,
@@ -616,9 +641,9 @@ e_shortcut_bar_set_canvas_style (EShortcutBar *shortcut_bar,
         rc_style->fg[GTK_STATE_NORMAL].green = 65535;
         rc_style->fg[GTK_STATE_NORMAL].blue  = 65535;
 
-        rc_style->bg[GTK_STATE_NORMAL].red   = 32512;
-        rc_style->bg[GTK_STATE_NORMAL].green = 32512;
-        rc_style->bg[GTK_STATE_NORMAL].blue  = 32512;
+        rc_style->bg[GTK_STATE_NORMAL].red   = 0x8000;
+        rc_style->bg[GTK_STATE_NORMAL].green = 0x8000;
+        rc_style->bg[GTK_STATE_NORMAL].blue  = 0x8000;
 
         gtk_widget_modify_style (GTK_WIDGET (canvas), rc_style);
         gtk_rc_style_unref (rc_style);
