@@ -71,6 +71,7 @@ static void e_vscrolled_bar_button_released (GtkWidget *button,
 					     EVScrolledBar *vscrolled_bar);
 static void e_vscrolled_bar_button_clicked (GtkWidget *button,
 					    EVScrolledBar *vscrolled_bar);
+static gboolean e_vscrolled_bar_scroll (gpointer data);
 static gboolean e_vscrolled_bar_timeout_handler (gpointer data);
 
 
@@ -632,7 +633,7 @@ e_vscrolled_bar_button_pressed (GtkWidget *button,
 	vscrolled_bar->min_distance = vscrolled_bar->adjustment->page_size / 4;
 	vscrolled_bar->button_pressed = TRUE;
 
-	e_vscrolled_bar_timeout_handler (vscrolled_bar);
+	e_vscrolled_bar_scroll (vscrolled_bar);
 }
 
 
@@ -659,9 +660,8 @@ e_vscrolled_bar_button_clicked (GtkWidget *button,
 	vscrolled_bar->button_pressed = FALSE;
 }
 
-
 static gboolean
-e_vscrolled_bar_timeout_handler (gpointer data)
+e_vscrolled_bar_scroll (gpointer data)
 {
 	EVScrolledBar *vscrolled_bar;
 	GtkAdjustment *adjustment;
@@ -671,13 +671,10 @@ e_vscrolled_bar_timeout_handler (gpointer data)
 	vscrolled_bar = E_VSCROLLED_BAR (data);
 	adjustment = vscrolled_bar->adjustment;
 
-	GDK_THREADS_ENTER ();
-
 	/* Check if the user has released the button and we have already
 	   scrolled the minimum distance. */
 	if (vscrolled_bar->button_pressed == FALSE
 	    && vscrolled_bar->min_distance <= 0) {
-		GDK_THREADS_LEAVE ();
 		return FALSE;
 	}
 
@@ -703,6 +700,18 @@ e_vscrolled_bar_timeout_handler (gpointer data)
 					 "value_changed");
 	}
 
+	return retval;
+}
+
+static gboolean
+e_vscrolled_bar_timeout_handler (gpointer data)
+{
+	gboolean retval = TRUE;
+
+	GDK_THREADS_ENTER ();
+
+	retval = e_vscrolled_bar_scroll (data);
+
 	GDK_THREADS_LEAVE ();
 	return retval;
 }
