@@ -287,7 +287,9 @@ ecmla_default (ECategoriesMasterListArray *ecmla)
 	ecmla->priv->categories = g_new (ECategoriesMasterListArrayItem *, BUILTIN_CATEGORY_COUNT);
 
 	for (i = 0; i < BUILTIN_CATEGORY_COUNT; i++) {
-		ecmla->priv->categories[i] = ecmlai_new (e_utf8_from_locale_string(_(builtin_categories[i].category)), builtin_categories[i].icon, NULL);
+		char *category = e_utf8_from_locale_string(_(builtin_categories[i].category));
+		ecmla->priv->categories[i] = ecmlai_new (category, builtin_categories[i].icon, NULL);
+		g_free (category);
 	}
 }
 
