@@ -69,6 +69,8 @@ static int e_categories_row_count (ETableModel *etc, gpointer data);
 static void *e_categories_value_at (ETableModel *etc, int col, int row, gpointer data);
 static void e_categories_set_value_at (ETableModel *etc, int col, int row, const void *val, gpointer data);
 static gboolean e_categories_is_cell_editable (ETableModel *etc, int col, int row, gpointer data);
+static gboolean e_categories_has_save_id (ETableModel *etc, gpointer data);
+static char *e_categories_get_save_id (ETableModel *etc, int row, gpointer data);
 static void *e_categories_duplicate_value (ETableModel *etc, int col, const void *value, gpointer data);
 static void e_categories_free_value (ETableModel *etc, int col, void *value, gpointer data);
 static void *e_categories_initialize_value (ETableModel *etc, int col, gpointer data);
@@ -503,9 +505,15 @@ e_categories_init (ECategories *categories)
 
 	categories->priv->model = e_table_simple_new(e_categories_col_count, 
 						     e_categories_row_count,
+						     NULL,
+
 						     e_categories_value_at,
 						     e_categories_set_value_at,
 						     e_categories_is_cell_editable,
+
+						     e_categories_has_save_id,
+						     e_categories_get_save_id,
+
 						     e_categories_duplicate_value,
 						     e_categories_free_value,
 						     e_categories_initialize_value,
@@ -689,7 +697,7 @@ e_categories_value_at (ETableModel *etc, int col, int row, gpointer data)
 {
 	ECategories *categories = E_CATEGORIES(data);
 	if (col == 0)
-		return (void *) categories->priv->selected_list[row];
+		return GINT_TO_POINTER (categories->priv->selected_list[row]);
 	else
 		return categories->priv->category_list[row];
 }
@@ -726,7 +734,8 @@ e_categories_set_value_at (ETableModel *etc, int col, int row, const void *val,
 {
 	ECategories *categories = E_CATEGORIES(data);
 	if ( col == 0 ) {
-		categories->priv->selected_list[row] = (gboolean) val;
+		categories->priv->selected_list[row] =
+			GPOINTER_TO_INT (val);
 		e_categories_rebuild (categories);
 	}
 	if ( col == 1 )
@@ -740,6 +749,20 @@ e_categories_is_cell_editable (ETableModel *etc, int col, int row, gpointer data
 	return col == 0;
 }
 
+static gboolean
+e_categories_has_save_id (ETableModel *etc, gpointer data)
+{
+	return TRUE;
+}
+
+static char *
+e_categories_get_save_id (ETableModel *etc, int row, gpointer data)
+{
+	ECategories *categories = E_CATEGORIES(data);
+
+	return strdup (categories->priv->category_list[row]);
+}
+
 /* This function duplicates the value passed to it. */
 static void *
 e_categories_duplicate_value (ETableModel *etc, int col, const void *value, gpointer data)
@@ -782,7 +805,7 @@ static char *
 e_categories_value_to_string (ETableModel *etc, int col, const void *value, gpointer data)
 {
 	if (col == 0)
-		return g_strdup_printf("%d", (int) value);
+		return g_strdup_printf("%d", GPOINTER_TO_INT (value));
 	else
 		return g_strdup(value);
 }
